@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008-2009 Aconex.  All Rights Reserved.
+ * Copyright (c) 2008-2011 Aconex.  All Rights Reserved.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -10,25 +10,21 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
 #include "local.h"
 #include <dirent.h>
 #include <search.h>
 #include <sys/stat.h>
+#ifdef HAVE_PWD_H
+#include <pwd.h>
+#endif
 
 static timers_t *timers;
 static int ntimers;
 static files_t *files;
 static int nfiles;
 
-extern void timer_callback(int, void *);
-extern void input_callback(scalar_t *, int, char *);
-
 char *
 local_strdup_suffix(const char *string, const char *suffix)
 {
@@ -53,6 +49,30 @@ local_strdup_prefix(const char *prefix, const char *string)
     return result;
 }
 
+int
+local_user(const char *username)
+{
+#ifdef HAVE_GETPWNAM
+    /* lose root privileges if we have them */
+    struct passwd *pw;
+
+    if ((pw = getpwnam(username)) == 0) {
+	__pmNotifyErr(LOG_WARNING,
+			"cannot find the user %s to switch to\n", username);
+	return -1;
+    }
+    if (setgid(pw->pw_gid) < 0 || setuid(pw->pw_uid) < 0) {
+	__pmNotifyErr(LOG_WARNING,
+			"cannot switch to uid/gid of user %s\n", username);
+	return -1;
+    }
+    return 0;
+#else
+    __pmNotifyErr(LOG_WARNING, "cannot switch to user %s\n", username);
+    return -1;
+#endif
+}
+
 int
 local_timer(double timeout, scalar_t *callback, int cookie)
 {
@@ -117,7 +137,7 @@ local_pipe(char *pipe, scalar_t *callback, int cookie)
     signal(SIGPIPE, SIG_IGN);
 #endif
     if (!fp) {
-	__pmNotifyErr(LOG_ERR, "popen failed (%s): %s", pipe, strerror(errno));
+	__pmNotifyErr(LOG_ERR, "popen failed (%s): %s", pipe, osstrerror());
 	exit(1);
     }
     me = local_file(FILE_PIPE, fileno(fp), callback, cookie);
@@ -128,18 +148,19 @@ local_pipe(char *pipe, scalar_t *callback, int cookie)
 int
 local_tail(char *file, scalar_t *callback, int cookie)
 {
-    int fd = open(file, O_RDONLY);
+    int fd = open(file, O_RDONLY | O_NDELAY);
     struct stat stats;
     int me;
 
     if (fd < 0) {
-	__pmNotifyErr(LOG_ERR, "open failed (%s): %s", file, strerror(errno));
+	__pmNotifyErr(LOG_ERR, "open failed (%s): %s", file, osstrerror());
 	exit(1);
     }
     if (fstat(fd, &stats) < 0) {
-	__pmNotifyErr(LOG_ERR, "fstat failed (%s): %s", file, strerror(errno));
+	__pmNotifyErr(LOG_ERR, "fstat failed (%s): %s", file, osstrerror());
 	exit(1);
     }
+    lseek(fd, 0L, SEEK_END);
     me = local_file(FILE_TAIL, fd, callback, cookie);
     files[me].me.tail.path = strdup(file);
     files[me].me.tail.dev = stats.st_dev;
@@ -155,11 +176,11 @@ local_sock(char *host, int port, scalar_t *callback, int cookie)
     int me, fd;
 
     if ((servinfo = gethostbyname(host)) == NULL) {
-	__pmNotifyErr(LOG_ERR, "gethostbyname (%s): %s", host, strerror(errno));
+	__pmNotifyErr(LOG_ERR, "gethostbyname (%s): %s", host, netstrerror());
 	exit(1);
     }
     if ((fd = __pmCreateSocket()) < 0) {
-	__pmNotifyErr(LOG_ERR, "socket (%s): %s", host, strerror(errno));
+	__pmNotifyErr(LOG_ERR, "socket (%s): %s", host, netstrerror());
 	exit(1);
     }
     memset(&myaddr, 0, sizeof(myaddr));
@@ -167,7 +188,7 @@ local_sock(char *host, int port, scalar_t *callback, int cookie)
     memcpy(&myaddr.sin_addr, servinfo->h_addr, servinfo->h_length);
     myaddr.sin_port = htons(port);
     if (connect(fd, (struct sockaddr *)&myaddr, sizeof(myaddr)) < 0) {
-	__pmNotifyErr(LOG_ERR, "connect (%s): %s", host, strerror(errno));
+	__pmNotifyErr(LOG_ERR, "connect (%s): %s", host, netstrerror());
 	exit(1);
     }
     me = local_file(FILE_SOCK, fd, callback, cookie);
@@ -229,7 +250,10 @@ local_atexit(void)
 	files = NULL;
     }
     /* take out any children we created */
-    __pmProcessTerminate(0, 0);
+#ifdef HAVE_SIGNAL
+    signal(SIGTERM, SIG_IGN);
+#endif
+    __pmProcessTerminate((pid_t)0, 0);
 }
 
 static void
@@ -243,17 +267,17 @@ local_log_rotated(files_t *file)
 	return;
 
     close(file->fd);
-    file->fd = open(file->me.tail.path, O_RDONLY);
+    file->fd = open(file->me.tail.path, O_RDONLY | O_NDELAY);
     if (file->fd < 0) {
-	__pmNotifyErr(LOG_ERR, "fopen failed after log rotate (%s): %s",
-			file->me.tail.path, strerror(errno));
+	__pmNotifyErr(LOG_ERR, "open failed after log rotate (%s): %s",
+			file->me.tail.path, osstrerror());
 	return;
     }
     files->me.tail.dev = stats.st_dev;
     files->me.tail.ino = stats.st_ino;
 }
 
-static int
+static void
 local_reconnector(files_t *file)
 {
     struct sockaddr_in myaddr;
@@ -292,7 +316,8 @@ local_pmdaMain(pmdaInterface *self)
     static char buffer[4096];
     int pmcdfd, nready, nfds, i, j, count, fd, maxfd = -1;
     fd_set fds, readyfds;
-    size_t bytes, offset;
+    ssize_t bytes;
+    size_t offset;
     char *s, *p;
 
     if ((pmcdfd = __pmdaInFd(self)) < 0)
@@ -321,8 +346,9 @@ local_pmdaMain(pmdaInterface *self)
 	memcpy(&readyfds, &fds, sizeof(readyfds));
 	nready = select(nfds, &readyfds, NULL, NULL, &timeout);
 	if (nready < 0) {
-	    if (errno != EINTR) {
-		__pmNotifyErr(LOG_ERR, "select failed: %s\n", strerror(errno));
+	    if (neterror() != EINTR) {
+		__pmNotifyErr(LOG_ERR, "select failed: %s\n",
+				netstrerror());
 		exit(1);
 	    }
 	    continue;
@@ -348,13 +374,18 @@ local_pmdaMain(pmdaInterface *self)
 multiread:
 	    bytes = read(fd, buffer + offset, sizeof(buffer)-1 - offset);
 	    if (bytes < 0) {
+		if ((files[i].type == FILE_TAIL) &&
+		    (oserror() == EINTR) ||
+		    (oserror() == EAGAIN) ||
+		    (oserror() == EWOULDBLOCK))
+		    continue;
 		if (files[i].type == FILE_SOCK) {
 		    close(files[i].fd);
 		    files[i].fd = -1;
 		    continue;
 		}
 		__pmNotifyErr(LOG_ERR, "Data read error on %s: %s\n",
-				local_filetype(files[i].type), strerror(errno));
+				local_filetype(files[i].type), osstrerror());
 		exit(1);
 	    }
 	    if (bytes == 0) {
@@ -390,43 +421,3 @@ multiread:
 	__pmAFunblock();
     }
 }
-
-static void
-local_pmns_path(__pmnsNode *base, FILE *f)
-{
-    if (base && base->parent) {
-	local_pmns_path(base->parent, f);
-	fprintf(f, "%s.", base->name);
-    }
-}
-
-/*
- * Print out all entries at the current level, including leaf nodes
- * (with PMIDs) then recursively descend into subtrees.
- */
-void
-local_pmns_write(__pmnsNode *base, FILE *f)
-{
-    __pmnsNode *np;
-
-    /* Print out full path to this part of the tree */
-    local_pmns_path(base->parent, f);
-    fprintf(f, "%s {\n", base->name);
-
-    /* Print out nodes at this level of the tree */
-    for (np = base->first; np != NULL; np = np->next) {
-	if (np->pmid == PM_ID_NULL)
-	    fprintf(f, "\t%s\n", np->name);
-	else
-	    fprintf(f, "\t%s\t\t%u:%u:%u\n", np->name,
-			pmid_domain(np->pmid),
-			pmid_cluster(np->pmid),
-			pmid_item(np->pmid));
-    }
-    fprintf(f, "}\n\n");
-
-    /* Print out all the children of this subtree */
-    for (np = base->first; np != NULL; np = np->next)
-	if (np->pmid == PM_ID_NULL)
-	    local_pmns_write(np, f);
-}
