@@ -1065,6 +1065,14 @@ __pmLogPutIndex(const __pmLogCtl *lcp, const __pmTimeval *tp)
 	assert(ti.ti_log >= 0);
     }
 
+#ifdef PCP_DEBUG
+    if (pmDebug & DBG_TRACE_LOG) {
+	fprintf(stderr, "__pmLogPutIndex: timestamp=%d.06%d vol=%d meta posn=%ld log posn=%ld\n",
+	    (int)ti.ti_stamp.tv_sec, (int)ti.ti_stamp.tv_usec,
+	    ti.ti_vol, (long)ti.ti_meta, (long)ti.ti_log);
+    }
+#endif
+
     oti.ti_stamp.tv_sec = htonl(ti.ti_stamp.tv_sec);
     oti.ti_stamp.tv_usec = htonl(ti.ti_stamp.tv_usec);
     oti.ti_vol = htonl(ti.ti_vol);
@@ -1314,9 +1322,7 @@ paranoidCheck(int len, __pmPDU *pb)
 static int
 paranoidLogRead(__pmLogCtl *lcp, int mode, FILE *peekf, pmResult **result)
 {
-    int		sts;
-    sts = __pmLogRead(lcp, mode, peekf, result, PMLOGREAD_TO_EOF);
-    return sts;
+    return __pmLogRead(lcp, mode, peekf, result, PMLOGREAD_TO_EOF);
 }
 
 /*
@@ -1452,7 +1458,7 @@ again:
      *  Decode
      *  <----  __pmPDUHdr  ----------->
      *  :---------:---------:---------:---------------- .........:
-     *  |   ???   |   ???   |   ???   | timestamp, .... pmResult |
+     *  | length  | pdutype |  anon   | timestamp, .... pmResult |
      *  :---------:---------:---------:---------------- .........:
      *  ^
      *  |
@@ -1508,6 +1514,10 @@ again:
 	return PM_ERR_LOGREC;
     }
     else {
+	__pmPDUHdr *header = (__pmPDUHdr *)pb;
+	header->len = sizeof(*header) + rlen;
+	header->type = PDU_RESULT;
+	header->from = FROM_ANON;
 	/* swab pdu buffer - done later in __pmDecodeResult */
     }
 
