@@ -13,7 +13,7 @@
  * 
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include "pmcd.h"
@@ -26,5 +26,7 @@
 PMCD_INTERN int	pmcd_hi_openfds = -1;   /* Highest open pmcd file descriptor */
 PMCD_INTERN int	_pmcd_done;		/* flag from pmcd pmda */
 PMCD_INTERN int	_pmcd_timeout = 5;	/* Timeout for hung agents */
+
+PMCD_INTERN AgentInfo *agent;		/* Array of agent info structs */
 PMCD_INTERN int	nAgents;		/* Number of active agents */
 
