@@ -18,6 +18,7 @@
 #include "pmapi.h"
 #include "impl.h"
 #include "pmda.h"
+#include "indom.h"
 #include <dirent.h>
 #include <ctype.h>
 #include <sys/stat.h>
@@ -35,14 +36,18 @@ static int maxbufindex;
 int
 refresh_proc_stat(proc_cpuinfo_t *proc_cpuinfo, proc_stat_t *proc_stat)
 {
+    pmdaIndom *idp = &indomtab[CPU_INDOM];
     char fmt[64];
-    int fd;
+    static int fd = -1; /* kept open until exit() */
     int n;
     int i;
     int j;
 
-    if ((fd = open("/proc/stat", O_RDONLY)) < 0)
-	return -errno;
+    if (fd >= 0)
+    	lseek(fd, 0, SEEK_SET);
+    else
+	if ((fd = open("/proc/stat", O_RDONLY)) < 0)
+	    return -oserror();
 
     for (n=0;;) {
 	if (n >= maxstatbuf) {
@@ -55,7 +60,6 @@ refresh_proc_stat(proc_cpuinfo_t *proc_cpuinfo, proc_stat_t *proc_stat)
 	    break;
     }
     statbuf[n] = '\0';
-    close(fd);
 
     if (bufindex == NULL) {
 	maxbufindex = 4;
@@ -76,8 +80,8 @@ refresh_proc_stat(proc_cpuinfo_t *proc_cpuinfo, proc_stat_t *proc_stat)
     }
 
     if (!started) {
-    	started = 1;
-	memset(proc_stat, 0, sizeof(proc_stat));
+	started = 1;
+	memset(proc_stat, 0, sizeof(*proc_stat));
 
 	/* hz of running kernel */
 	proc_stat->hz = sysconf(_SC_CLK_TCK);
@@ -89,14 +93,15 @@ refresh_proc_stat(proc_cpuinfo_t *proc_cpuinfo, proc_stat_t *proc_stat)
 	}
 	if (proc_stat->ncpu == 0)
 	    proc_stat->ncpu = 1; /* non-SMP kernel? */
+	proc_stat->cpu_indom = idp;
 	proc_stat->cpu_indom->it_numinst = proc_stat->ncpu;
 	proc_stat->cpu_indom->it_set = (pmdaInstid *)malloc(
 		proc_stat->ncpu * sizeof(pmdaInstid));
 	/*
 	 * Map out the CPU instance domain.
-	 * If we have "sapic" in /proc/cpuinfo,
-	 * then use cpu:M.S.C naming (Module, Slot, Cpu)
-	 * else just use cpu[0-9]* naming
+	 *
+	 * The first call to cpu_name() does initialization on the
+	 * proc_cpuinfo structure.
 	 */
 	for (i=0; i < proc_stat->ncpu; i++) {
 	    proc_stat->cpu_indom->it_set[i].i_inst = i;
@@ -113,8 +118,31 @@ refresh_proc_stat(proc_cpuinfo_t *proc_cpuinfo, proc_stat_t *proc_stat)
 	proc_stat->p_sirq = (unsigned long long *)calloc(1, n);
 	proc_stat->p_steal = (unsigned long long *)calloc(1, n);
 	proc_stat->p_guest = (unsigned long long *)calloc(1, n);
+
+	n = proc_cpuinfo->node_indom->it_numinst * sizeof(unsigned long long);
+	proc_stat->n_user = calloc(1, n);
+	proc_stat->n_nice = calloc(1, n);
+	proc_stat->n_sys = calloc(1, n);
+	proc_stat->n_idle = calloc(1, n);
+	proc_stat->n_wait = calloc(1, n);
+	proc_stat->n_irq = calloc(1, n);
+	proc_stat->n_sirq = calloc(1, n);
+	proc_stat->n_steal = calloc(1, n);
+	proc_stat->n_guest = calloc(1, n);
     }
 
+    /* reset per-node stats */
+    n = proc_cpuinfo->node_indom->it_numinst * sizeof(unsigned long long);
+    memset(proc_stat->n_user, 0, n);
+    memset(proc_stat->n_nice, 0, n);
+    memset(proc_stat->n_sys, 0, n);
+    memset(proc_stat->n_idle, 0, n);
+    memset(proc_stat->n_wait, 0, n);
+    memset(proc_stat->n_irq, 0, n);
+    memset(proc_stat->n_sirq, 0, n);
+    memset(proc_stat->n_steal, 0, n);
+    memset(proc_stat->n_guest, 0, n);
+
     /*
      * cpu  95379 4 20053 6502503
      * 2.6 kernels have 3 additional fields
@@ -158,6 +186,7 @@ refresh_proc_stat(proc_cpuinfo_t *proc_cpuinfo, proc_stat_t *proc_stat)
 		if (strncmp("cpu", bufindex[j], 3) == 0 && isdigit(bufindex[j][3])) {
 		    int c;
 		    int cpunum = atoi(&bufindex[j][3]);
+		    int node;
 		    if (cpunum >= 0 && cpunum < proc_stat->ncpu) {
 			n = sscanf(bufindex[j], fmt, &c,
 			    &proc_stat->p_user[cpunum],
@@ -169,6 +198,17 @@ refresh_proc_stat(proc_cpuinfo_t *proc_cpuinfo, proc_stat_t *proc_stat)
 			    &proc_stat->p_sirq[cpunum],
 			    &proc_stat->p_steal[cpunum],
 			    &proc_stat->p_guest[cpunum]);
+			if ((node = proc_cpuinfo->cpuinfo[cpunum].node) != -1) {
+			    proc_stat->n_user[node] += proc_stat->p_user[cpunum];
+			    proc_stat->n_nice[node] += proc_stat->p_nice[cpunum];
+			    proc_stat->n_sys[node] += proc_stat->p_sys[cpunum];
+			    proc_stat->n_idle[node] += proc_stat->p_idle[cpunum];
+			    proc_stat->n_wait[node] += proc_stat->p_wait[cpunum];
+			    proc_stat->n_irq[node] += proc_stat->p_irq[cpunum];
+			    proc_stat->n_sirq[node] += proc_stat->p_sirq[cpunum];
+			    proc_stat->n_steal[node] += proc_stat->p_steal[cpunum];
+			    proc_stat->n_guest[node] += proc_stat->p_guest[cpunum];
+			}
 		    }
 		}
 	    }
