@@ -69,6 +69,8 @@ static struct {
     		"Trace metrics class operations" },
     { DBG_TRACE_DERIVE,		"DERIVE",
     		"Derived metrics operations" },
+    { DBG_TRACE_LOCK,		"LOCK",
+    		"Trace locks (if multi-threading enabled)" },
     { DBG_TRACE_INTERP,		"INTERP",
 		"Diags for value interpolation in archives" },
     { DBG_TRACE_CONFIG,		"CONFIG",
