@@ -14,7 +14,7 @@
 # 
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 # 
 # Administrative script to check pmie processes are alive, and restart
 # them as required.
@@ -83,6 +83,8 @@ then
     #  force it to a known IRIX location
     PWDCMND=/bin/pwd
 fi
+eval $PWDCMND -P >/dev/null 2>&1
+[ $? -eq 0 ] && PWDCMND="$PWDCMND -P"
 
 # determine whether SGI Embedded Support Partner events need to be used
 CONFARGS="-F"
@@ -160,7 +162,7 @@ _message()
     case $1
     in
 	'restart')
-	    $PCP_ECHO_PROG $PCP_ECHO_N "Restarting pmie for host \"$host\" ..."
+	    $PCP_ECHO_PROG $PCP_ECHO_N "Restarting pmie for host \"$host\" ...""$PCP_ECHO_C"
 	    ;;
     esac
 }
@@ -464,8 +466,7 @@ s/^\([A-Za-z][A-Za-z0-9_]*\)=/export \1; \1=/p
 	p_pmcd_host=""
 
 	# throw away stderr in case $file has been removed by now
-	eval `strings $file 2>/dev/null | sed -e '/^$/d' | sed -e 3q \
-	| $PCP_AWK_PROG '
+	eval `$PCP_BINADM_DIR/pmiestatus $file 2>/dev/null | $PCP_AWK_PROG '
 NR == 2	{ printf "p_logfile=\"%s\"\n", $0; next }
 NR == 3	{ printf "p_pmcd_host=\"%s\"\n", $0; next }
 	{ next }'`
@@ -523,7 +524,6 @@ NR == 3	{ printf "p_pmcd_host=\"%s\"\n", $0; next }
 		if sed 1q $configfile | grep '^#pmieconf-rules [0-9]' >/dev/null
 		then
 		    # pmieconf file, see if re-generation is needed
-		    # Note that pmieconf is in the pcp-pro product (not open source)
 		    #
 		    cp $configfile $tmp.pmie
 		    if $have_pmieconf
@@ -556,7 +556,6 @@ NR == 3	{ printf "p_pmcd_host=\"%s\"\n", $0; next }
 		fi
 	    else
 		# file does not exist, generate it, if possible
-		# Note that pmieconf is in the pcp-pro product (not open source)
 		# 
 		if $have_pmieconf
 		then
