@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  * 
  * The analysis of how to organize the fetching of metrics (pragmatics),
  * and any other parts of the inference engine sensitive to details of
@@ -442,7 +442,7 @@ sendDesc(Expr *x, pmValueSet *vset)
 	d.sem = PM_SEM_INSTANT;
 	d.units = noUnits;
     }
-    __pmSendDesc(STDOUT_FILENO, PDU_BINARY, &d);
+    __pmSendDesc(STDOUT_FILENO, pmWhichContext(), &d);
 }
 
 
@@ -648,6 +648,7 @@ initMetric(Metric *m)
     if (m->desc.type == PM_TYPE_STRING ||
 	m->desc.type == PM_TYPE_AGGREGATE ||
 	m->desc.type == PM_TYPE_AGGREGATE_STATIC ||
+	m->desc.type == PM_TYPE_EVENT ||
 	m->desc.type == PM_TYPE_UNKNOWN) {
 	fprintf(stderr, "%s: metric %s has non-numeric type\n", pmProgname, mname);
 	ret = -1;
@@ -821,6 +822,7 @@ reinitMetric(Metric *m)
     if (m->desc.type == PM_TYPE_STRING ||
 	m->desc.type == PM_TYPE_AGGREGATE ||
 	m->desc.type == PM_TYPE_AGGREGATE_STATIC ||
+	m->desc.type == PM_TYPE_EVENT ||
 	m->desc.type == PM_TYPE_UNKNOWN) {
 	fprintf(stderr, "%s: metric %s has non-numeric type\n", pmProgname, mname);
 	ret = -1;
