@@ -12,12 +12,9 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
+#include <assert.h>
 #include "pmapi.h"
 #include "impl.h"
 
@@ -41,6 +38,7 @@ _pmLogGet(__pmLogCtl *lcp, int vol, __pmPDU **pb)
 	f = lcp->l_mfp;
 
     offset = ftell(f);
+    assert(offset >= 0);
 #ifdef PCP_DEBUG
     if (pmDebug & DBG_TRACE_LOG) {
 	fprintf(stderr, "_pmLogGet: fd=%d vol=%d posn=%ld ",
@@ -69,38 +67,43 @@ again:
 	}
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_LOG)
-	    fprintf(stderr, "Error: hdr fread=%d %s\n", sts, strerror(errno));
+	    fprintf(stderr, "Error: hdr fread=%d %s\n", sts, osstrerror());
 #endif
 	if (sts > 0)
 	    return PM_ERR_LOGREC;
 	else
-	    return -errno;
+	    return -oserror();
     }
 
     if ((lpb = (__pmPDU *)malloc(ntohl(head))) == NULL) {
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_LOG)
-	    fprintf(stderr, "Error: __pmFindPDUBuf(%d) %s\n",
-		(int)ntohl(head), strerror(errno));
+	    fprintf(stderr, "Error: _pmLogGet:(%d) %s\n",
+		(int)ntohl(head), osstrerror());
 #endif
 	fseek(f, offset, SEEK_SET);
-	return -errno;
+	return -oserror();
     }
 
     lpb[0] = head;
     if ((sts = (int)fread(&lpb[1], 1, ntohl(head) - sizeof(head), f)) != ntohl(head) - sizeof(head)) {
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_LOG)
-	    fprintf(stderr, "Error: data fread=%d %s\n", sts, strerror(errno));
+	    fprintf(stderr, "Error: data fread=%d %s\n", sts, osstrerror());
 #endif
 	if (sts == 0) {
 	    fseek(f, offset, SEEK_SET);
+	    free(lpb);
 	    return PM_ERR_EOL;
 	}
-	else if (sts > 0)
+	else if (sts > 0) {
+	    free(lpb);
 	    return PM_ERR_LOGREC;
-	else
-	    return -errno;
+	}
+	else {
+	    free(lpb);
+	    return -oserror();
+	}
     }
 
 
@@ -112,6 +115,7 @@ again:
 	    fprintf(stderr, "Error: head-tail mismatch (%d-%d)\n",
 		(int)ntohl(head), (int)ntohl(tail));
 #endif
+	free(lpb);
 	return PM_ERR_LOGREC;
     }
 
@@ -180,9 +184,9 @@ _pmLogPut(FILE *f, __pmPDU *pb)
     if ((sts = (int)fwrite(pb, 1, rlen, f)) != rlen) {
 #ifdef PCP_DEBUG
 	if (pmDebug & DBG_TRACE_LOG)
-	    fprintf(stderr, "_pmLogPut: fwrite=%d %s\n", sts, strerror(errno));
+	    fprintf(stderr, "_pmLogPut: fwrite=%d %s\n", sts, osstrerror());
 #endif
-	return -errno;
+	return -oserror();
     }
     return 0;
 }
